function scatterplot(selector, data, xAttr, yAttr) {
  // Set up the SVG element
  var svg = d3
    .select(selector)
    .append("svg")
    .attr("width", 600)
    .attr("height", 500)
    .style("display", "block")
    .style("margin", "auto");

  // Define scales for x and y attributes
  var xScale = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, function (d) {
        return d[xAttr];
      }),
    ])
    .range([100, 500]);

  var yScale = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, function (d) {
        return d[yAttr];
      }),
    ])
    .range([400, 100]);

  // Add x-axis
  svg
    .append("g")
    .attr("class", "x-axis")
    .attr("transform", "translate(0, 400)")
    .call(d3.axisBottom(xScale));

  // Add y-axis
  svg
    .append("g")
    .attr("class", "y-axis")
    .attr("transform", "translate(100, 0)")
    .call(d3.axisLeft(yScale));

  // Add circles for each data point
  svg
    .selectAll("circle")
    .data(data)
    .enter()
    .append("circle")
    .attr("cx", function (d) {
      return xScale(d[xAttr]);
    })
    .attr("cy", function (d) {
      return yScale(d[yAttr]);
    })
    .attr("r", 5)
    .attr("fill", "blue")
    .attr("stroke", "black")
    .attr("stroke-width", "1px");
}
